==> enterprisemodules-wls_config-3.5.0.tar.gz: enterprisemodules-wls_config-3.5.0/documentation/wls_managed_executor_service_template.md <==
---
title: wls managed executor service template
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

Weblogic Server provides a preconfigured, default ManagedExecutorService for each application, and applications can easily use it in web or EJB components
without any configuration.

This resource allows you to manage a ManagedExecutorService in an WebLogic domain.

Here is an example on how you should use this:

    wls_managed_executor_service_template { 'default/ManagedExecutorServiceTemplate-0':
      ensure                               => 'present',
      deployment_order                     => '1000',
      long_running_priority                => '5',
      max_concurrent_long_running_requests => '10',
      target                               => ['ClusterJMS'],
      targettype                           => ['Cluster'],
    }

## Attributes



Attribute Name                                                                                                      | Short Description                                                                         |
------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[deployment_order](#wls_managed_executor_service_template_deployment_order)                                         | A priority that the server uses to determine when it deploys an item.                     |
[disable_corrective_change](#wls_managed_executor_service_template_disable_corrective_change)                       | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_managed_executor_service_template_disable_corrective_ensure)                       | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[dispatch_policy](#wls_managed_executor_service_template_dispatch_policy)                                           |  The name of the Work Manager to use for this Concurrent Managed Ojbect (CMO).            |
[domain](#wls_managed_executor_service_template_domain)                                                             | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_managed_executor_service_template_ensure)                                                             | The basic property that the resource should be in.                                        |
[long_running_priority](#wls_managed_executor_service_template_long_running_priority)                               |  An integer that specifies the long-running daemon thread's priority.                     |
[max_concurrent_long_running_requests](#wls_managed_executor_service_template_max_concurrent_long_running_requests) |  The maximum number of running long-running tasks submitted to this CMO.                  |
[name](#wls_managed_executor_service_template_name)                                                                 | The name.                                                                                 |
[notes](#wls_managed_executor_service_template_notes)                                                               | Optional information that you can include to describe this configuration.                 |
[provider](#wls_managed_executor_service_template_provider)                                                         | resource.                                                                                 |
[target](#wls_managed_executor_service_template_target)                                                             | An array of target names.                                                                 |
[targettype](#wls_managed_executor_service_template_targettype)                                                     | An array of target types.                                                                 |
[template_name](#wls_managed_executor_service_template_template_name)                                               | The template name
                                                                        |
[timeout](#wls_managed_executor_service_template_timeout)                                                           | Timeout for applying a resource.                                                          |




### deployment_order<a name='wls_managed_executor_service_template_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       deployment_order => '1000'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### disable_corrective_change<a name='wls_managed_executor_service_template_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change' parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not modify the resource
    and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_managed_executor_service_template](#attributes)

### disable_corrective_ensure<a name='wls_managed_executor_service_template_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure' parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

    When a corrective ensure does happen on the resource Puppet will not create or remove the resource
    and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_managed_executor_service_template](#attributes)

### dispatch_policy<a name='wls_managed_executor_service_template_dispatch_policy'>

 The name of the Work Manager to use for this Concurrent Managed Ojbect (CMO). If a Work Manager is not specified, the default one is used.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       dispatch_policy => 'a_value'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### domain<a name='wls_managed_executor_service_template_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_managed_executor_service_template](#attributes)

### ensure<a name='wls_managed_executor_service_template_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_managed_executor_service_template](#attributes)

### long_running_priority<a name='wls_managed_executor_service_template_long_running_priority'>

 An integer that specifies the long-running daemon thread's priority. If a value is specified, all long-running threads are affected.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       long_running_priority => '5'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### max_concurrent_long_running_requests<a name='wls_managed_executor_service_template_max_concurrent_long_running_requests'>

 The maximum number of running long-running tasks submitted to this CMO.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       max_concurrent_long_running_requests => '10'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### name<a name='wls_managed_executor_service_template_name'>

The name.



[Back to overview of wls_managed_executor_service_template](#attributes)

### notes<a name='wls_managed_executor_service_template_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       notes => 'a_value'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### provider<a name='wls_managed_executor_service_template_provider'>

The specific backend to use for this `wls_managed_executor_service_template`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a managed executor service (MES) template. via regular WLST



[Back to overview of wls_managed_executor_service_template](#attributes)

### target<a name='wls_managed_executor_service_template_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_managed_executor_service_template](#attributes)

### targettype<a name='wls_managed_executor_service_template_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_managed_executor_service_template](#attributes)

### template_name<a name='wls_managed_executor_service_template_template_name'>

The template name



[Back to overview of wls_managed_executor_service_template](#attributes)

### timeout<a name='wls_managed_executor_service_template_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_managed_executor_service_template](#attributes)

==> enterprisemodules-wls_config-3.6.0.tar.gz: enterprisemodules-wls_config-3.6.0/documentation/wls_managed_executor_service_template.md <==
---
title: wls managed executor service template
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

Weblogic Server provides a preconfigured, default ManagedExecutorService for each application, and applications can easily use it in web or EJB components
without any configuration.

This resource allows you to manage a ManagedExecutorService in an WebLogic domain.

Here is an example on how you should use this:

    wls_managed_executor_service_template { 'default/ManagedExecutorServiceTemplate-0':
      ensure                               => 'present',
      deployment_order                     => '1000',
      long_running_priority                => '5',
      max_concurrent_long_running_requests => '10',
      target                               => ['ClusterJMS'],
      targettype                           => ['Cluster'],
    }

## Attributes



Attribute Name                                                                                                      | Short Description                                                                         |
------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------- |
[deployment_order](#wls_managed_executor_service_template_deployment_order)                                         | A priority that the server uses to determine when it deploys an item.                     |
[disable_corrective_change](#wls_managed_executor_service_template_disable_corrective_change)                       | Disable the modification of a resource when Puppet decides it is a corrective change.     |
[disable_corrective_ensure](#wls_managed_executor_service_template_disable_corrective_ensure)                       | Disable the creation or removal of a resource when Puppet decides is a corrective change. |
[dispatch_policy](#wls_managed_executor_service_template_dispatch_policy)                                           |  The name of the Work Manager to use for this Concurrent Managed Ojbect (CMO).            |
[domain](#wls_managed_executor_service_template_domain)                                                             | With this parameter, you identify the domain, where your objects is in.                   |
[ensure](#wls_managed_executor_service_template_ensure)                                                             | The basic property that the resource should be in.                                        |
[long_running_priority](#wls_managed_executor_service_template_long_running_priority)                               |  An integer that specifies the long-running daemon thread's priority.                     |
[max_concurrent_long_running_requests](#wls_managed_executor_service_template_max_concurrent_long_running_requests) |  The maximum number of running long-running tasks submitted to this CMO.                  |
[name](#wls_managed_executor_service_template_name)                                                                 | The name.                                                                                 |
[notes](#wls_managed_executor_service_template_notes)                                                               | Optional information that you can include to describe this configuration.                 |
[provider](#wls_managed_executor_service_template_provider)                                                         | resource.                                                                                 |
[target](#wls_managed_executor_service_template_target)                                                             | An array of target names.                                                                 |
[targettype](#wls_managed_executor_service_template_targettype)                                                     | An array of target types.                                                                 |
[template_name](#wls_managed_executor_service_template_template_name)                                               | The template name
                                                                        |
[timeout](#wls_managed_executor_service_template_timeout)                                                           | Timeout for applying a resource.                                                          |




### deployment_order<a name='wls_managed_executor_service_template_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       deployment_order => '1000'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### disable_corrective_change<a name='wls_managed_executor_service_template_disable_corrective_change'>

Disable the modification of a resource when Puppet decides it is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_change` parameter, you can disable corrective changes on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ...
      disable_corrective_change => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not modify the resource
and signal an error:

        Error: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/parameter: change from '10' to '20' failed: Corrective change present requested by catalog, but disabled by parameter disable_corrective_change. (corrective)



[Back to overview of wls_managed_executor_service_template](#attributes)

### disable_corrective_ensure<a name='wls_managed_executor_service_template_disable_corrective_ensure'>

Disable the creation or removal of a resource when Puppet decides is a corrective change.

(requires easy_type V2.11.0 or higher)

When using a Puppet Server, Puppet knows about adaptive and corrective changes. A corrective change
is when Puppet notices that the resource has changed, but the catalog has not changed. This can occur
for example, when a user, by accident or willingly, changed something on the system that Puppet is
managing. The normal Puppet process then repairs this and puts the resource back in the state as defined
in the catalog. This process is precisely what you want most of the time, but not always. This can
sometimes also occur when a hardware or network error occurs. Then Puppet cannot correctly determine
the current state of the system and thinks the resource is changed, while in fact, it is not. Letting
Puppet recreate remove or change the resource in these cases, is NOT wat you want.

Using the `disable_corrective_ensure` parameter, you can disable corrective ensure present or ensure absent actions on the current resource.

Here is an example of this:

    crucial_resource {'be_carefull':
      ensure                    => 'present',
      ...
      disable_corrective_ensure => true,
      ...
    }

When a corrective ensure does happen on the resource Puppet will not create or remove the resource
and signal an error:

        Error: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure.
        Error: /Stage[main]/Main/Crucial_resource[be_carefull]/ensure: change from 'absent' to 'present' failed: Corrective ensure present requested by catalog, but disabled by parameter disable_corrective_ensure. (corrective)



[Back to overview of wls_managed_executor_service_template](#attributes)

### dispatch_policy<a name='wls_managed_executor_service_template_dispatch_policy'>

 The name of the Work Manager to use for this Concurrent Managed Ojbect (CMO). If a Work Manager is not specified, the default one is used.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       dispatch_policy => 'a_value'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### domain<a name='wls_managed_executor_service_template_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_managed_executor_service_template](#attributes)

### ensure<a name='wls_managed_executor_service_template_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_managed_executor_service_template](#attributes)

### long_running_priority<a name='wls_managed_executor_service_template_long_running_priority'>

 An integer that specifies the long-running daemon thread's priority. If a value is specified, all long-running threads are affected.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       long_running_priority => '5'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### max_concurrent_long_running_requests<a name='wls_managed_executor_service_template_max_concurrent_long_running_requests'>

 The maximum number of running long-running tasks submitted to this CMO.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       max_concurrent_long_running_requests => '10'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### name<a name='wls_managed_executor_service_template_name'>

The name.



[Back to overview of wls_managed_executor_service_template](#attributes)

### notes<a name='wls_managed_executor_service_template_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  Note: If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds.

An example on how to use this:

    wls_managed_executor_service_template {a_wls_managed_executor_service_template :
       ...
       notes => 'a_value'
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_managed_executor_service_template](#attributes)

### provider<a name='wls_managed_executor_service_template_provider'>

The specific backend to use for this `wls_managed_executor_service_template`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a managed executor service (MES) template. via regular WLST



[Back to overview of wls_managed_executor_service_template](#attributes)

### target<a name='wls_managed_executor_service_template_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_managed_executor_service_template](#attributes)

### targettype<a name='wls_managed_executor_service_template_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_managed_executor_service_template](#attributes)

### template_name<a name='wls_managed_executor_service_template_template_name'>

The template name



[Back to overview of wls_managed_executor_service_template](#attributes)

### timeout<a name='wls_managed_executor_service_template_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_managed_executor_service_template](#attributes)
